<?php
/*
 * Plugin Name:       Woo Product Weight (EasyToolsWP)
 * Plugin URI:        https://www.easytoolswp.com/plugins/woocommerce/etwp-product-weight.zip
 * Description:       Add weight to products and display it on product pages, cart, and checkout.
 * Version:           1.0.1
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 * Author URI:        https://www.easytoolswp.com/product-weight/
 * Update URI:        https://www.easytoolswp.com/plugins/woocommerce/etwp-product-weight.zip
 * Requires Plugins:  woocommerce
 */

// Tilføj felt til produktredigeringssiden
add_action('woocommerce_product_options_general_product_data', 'add_product_weight_field');
function add_product_weight_field() {
    woocommerce_wp_text_input(array(
        'id' => '_product_weight',
        'label' => __('Product Weight (grams)', 'woocommerce'),
        'placeholder' => '',
        'description' => __('Enter the weight of the product in grams.', 'woocommerce')
    ));
}

// Gem produktvægt
add_action('woocommerce_process_product_meta', 'save_product_weight');
function save_product_weight($post_id) {
    $product_weight = isset($_POST['_product_weight']) ? sanitize_text_field($_POST['_product_weight']) : '';
    update_post_meta($post_id, '_product_weight', $product_weight);
}

// Vis produktvægt under prisen på produktsiden
add_action('woocommerce_single_product_summary', 'display_product_weight_on_single_product', 10);
function display_product_weight_on_single_product() {
    global $product;
    $weight = $product->get_meta('_product_weight', true);
    if ($weight) {
        echo '<p class="product-weight">' . __('Pris pr. ', 'woocommerce') . $weight . ' gram</p>';
    }
}

// Vis produktvægt under prisen på varekortet
add_action('woocommerce_after_shop_loop_item', 'display_product_weight_in_shop_loop', 9);
function display_product_weight_in_shop_loop() {
    global $product;
    $weight = $product->get_meta('_product_weight', true);
    if ($weight) {
        echo '<p class="product-weight">' . __('', 'woocommerce') . $weight . ' g</p>';
    }
}

// Tilføj produktvægt ved siden af prisen i kurven
add_filter('woocommerce_cart_item_price', 'display_product_weight_in_cart', 10, 3);
function display_product_weight_in_cart($product_price, $cart_item, $cart_item_key) {
    $product = $cart_item['data'];
    $weight = $product->get_meta('_product_weight', true);
    if ($weight) {
        $total_weight = intval($weight);
        $product_price .= '<br><span class="product-weight">' . __('', 'woocommerce') . $total_weight . ' g</span>';
    }
    return $product_price;
}

// Tilføj produktvægt ved siden af prisen i kassen
add_filter('woocommerce_checkout_cart_item_quantity', 'display_product_weight_in_checkout', 10, 3);
function display_product_weight_in_checkout($quantity_html, $cart_item, $cart_item_key) {
    $product = $cart_item['data'];
    $weight = $product->get_meta('_product_weight', true);
    if ($weight) {
        $total_weight = intval($weight) * $cart_item['quantity'];
        $quantity_html .= '<br><span class="product-weight">' . __('Total gram: ', 'woocommerce') . $total_weight . ' g</span>';
    }
    return $quantity_html;
}

// Beregn og vis den samlede vægt i kurven
add_action('woocommerce_cart_totals_after_order_total', 'display_cart_total_weight', 20 );
function display_cart_total_weight() {
    $total_weight = 0;
    foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
        $product = $cart_item['data'];
        $weight = $product->get_meta('_product_weight', true);
        if ($weight) {
            $total_weight += intval($weight) * $cart_item['quantity'];
        }
    }
    echo '<tr class="cart-total-weight"><td colspan="4">' . __('Total gram:', 'woocommerce') . '</td><td width="160">' . $total_weight . ' g</td></tr>';
}

// Flyt produktvægt til subtotal i kurven
add_filter('woocommerce_cart_item_subtotal', 'move_product_weight_to_subtotal', 10, 3);
function move_product_weight_to_subtotal($product_subtotal, $cart_item, $cart_item_key) {
    $product = $cart_item['data'];
    $weight = $product->get_meta('_product_weight', true);
    if ($weight) {
        $total_weight = intval($weight) * $cart_item['quantity'];
        $product_subtotal .= '<br><span class="product-weight">' . __('', 'woocommerce') . $total_weight . ' g</span>';
    }
    return $product_subtotal;
}


// Beregn og vis den samlede vægt i kassen
add_action('woocommerce_review_order_after_order_total', 'display_checkout_total_weight', 20 );
function display_checkout_total_weight() {
    $total_weight = 0;
    foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
        $product = $cart_item['data'];
        $weight = $product->get_meta('_product_weight', true);
        if ($weight) {
            $total_weight += intval($weight) * $cart_item['quantity'];
        }
    }
    echo '<tr class="order-total"><td>' . __('Total gram:', 'woocommerce') . '</td><td>Bland-selv-slik: ' . $total_weight . ' g</td></tr>';
}

// Tilføj JavaScript til wp_footer hook
add_action('wp_footer', 'add_custom_js_to_footer');
function add_custom_js_to_footer() {
    ?>
    <script type="text/javascript">
        jQuery(function($) {
            $(document.body).on('added_to_cart', function() {
                // Foretag en AJAX-anmodning for at opdatere shortcode-udgangen
                $.ajax({
                    type: 'POST',
                    url: '<?php echo admin_url('admin-ajax.php'); ?>',
                    data: {
                        action: 'update_cart_total_weight'
                    },
                    success: function(response) {
                        $('.cart-total-weight').replaceWith(response);
                    }
                });
            });
        });
    </script>
    <?php
}

// Håndter AJAX-anmodningen for at opdatere den samlede vægt i kurven
add_action('wp_ajax_update_cart_total_weight', 'update_cart_total_weight_callback');
add_action('wp_ajax_nopriv_update_cart_total_weight', 'update_cart_total_weight_callback');

function update_cart_total_weight_callback() {
    ob_start();
    $total_weight = 0;
    foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
        $product = $cart_item['data'];
        $weight = $product->get_meta('_product_weight', true);
        if ($weight) {
            $total_weight += intval($weight) * $cart_item['quantity'];
        }
    }
    echo '<div class="cart-total-weight">' . __('', 'woocommerce') . ' ' . $total_weight . ' gram i posen</div>';
    wp_die();
}

// Opret shortcode for at vise den samlede vægt i kurven
add_shortcode('cart_total_weight', 'display_cart_total_weight_shortcode');
function display_cart_total_weight_shortcode() {
    ob_start();
    $total_weight = 0;
    foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
        $product = $cart_item['data'];
        $weight = $product->get_meta('_product_weight', true);
        if ($weight) {
            $total_weight += intval($weight) * $cart_item['quantity'];
        }
    }
    echo '<div class="cart-total-weight">' . __('', 'woocommerce') . ' ' . $total_weight . ' gram i posen</div>';
    return ob_get_clean();
}
